summaryrefslogtreecommitdiff
path: root/gdb/ppc-linux-tdep.c
diff options
context:
space:
mode:
authorJim Blandy <jimb@codesourcery.com>2003-06-17 16:06:18 +0000
committerJim Blandy <jimb@codesourcery.com>2003-06-17 16:06:18 +0000
commita7fa6674d52c3a0c68d817e5d5f9cd6442f3a308 (patch)
tree53b1441020993971d8b44beee98602d3fd98319a /gdb/ppc-linux-tdep.c
parent58f4fc102a6b31540990d88dc625ca9fbcd6cd45 (diff)
downloadgdb-a7fa6674d52c3a0c68d817e5d5f9cd6442f3a308.tar.gz
* ppc-linux-tdep.c: "Linux" -> "GNU/Linux"
Diffstat (limited to 'gdb/ppc-linux-tdep.c')
-rw-r--r--gdb/ppc-linux-tdep.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gdb/ppc-linux-tdep.c b/gdb/ppc-linux-tdep.c
index f2d76b8b11b..ab038b7a2e9 100644
--- a/gdb/ppc-linux-tdep.c
+++ b/gdb/ppc-linux-tdep.c
@@ -770,12 +770,12 @@ static struct insn_pattern ppc64_standard_linkage[] =
(sizeof (ppc64_standard_linkage) / sizeof (ppc64_standard_linkage[0]))
/* Recognize a 64-bit PowerPC Linux linkage function --- what GDB
calls a "solib trampoline". */
static int
ppc64_in_solib_call_trampoline (CORE_ADDR pc, char *name)
{
/* Detecting solib call trampolines on PPC64 Linux is a pain.
It's not specifically solib call trampolines that are the issue.
Any call from one function to another function that uses a
@@ -787,7 +787,7 @@ ppc64_in_solib_call_trampoline (CORE_ADDR pc, char *name)
also an inter-TOC call, and requires a trampoline --- so "solib
call trampolines" are just a special case.
- The 64-bit PowerPC Linux ABI calls these call trampolines
+ The 64-bit PowerPC GNU/Linux ABI calls these call trampolines
"linkage functions". Since they need to be near the functions
that call them, they all appear in .text, not in any special
section. The .plt section just contains an array of function
@@ -770,12 +770,12 @@ static struct insn_pattern ppc64_standard_linkage[] =
(sizeof (ppc64_standard_linkage) / sizeof (ppc64_standard_linkage[0]))
-/* Recognize a 64-bit PowerPC Linux linkage function --- what GDB
+/* Recognize a 64-bit PowerPC GNU/Linux linkage function --- what GDB
calls a "solib trampoline". */
static int
@@ -770,12 +770,12 @@ static struct insn_pattern ppc64_standard_linkage[] =
ppc64_in_solib_call_trampoline (CORE_ADDR pc, char *name)
{
- /* Detecting solib call trampolines on PPC64 Linux is a pain.
+ /* Detecting solib call trampolines on PPC64 GNU/Linux is a pain.
It's not specifically solib call trampolines that are the issue.
Any call from one function to another function that uses a